@@ -3,8 +3,8 @@
 Author: Christof Angermueller <cangermueller@gmail.com>
 """
 
-import os
 from functools import reduce
+from pathlib import Path
 
 import numpy as np
 
@@ -285,7 +285,7 @@ def var_tag(var):
             path, line, _, src = tag.trace[0][-1]
         else:
             path, line, _, src = tag.trace[0]
-        path = os.path.basename(path)
+        path = Path(path).name
         path = path.replace("<", "")
         path = path.replace(">", "")
         src = src.encode()
@@ -360,7 +360,7 @@ def dict_to_pdnode(d):
     for k, v in d.items():
         if v is not None:
             if isinstance(v, list):
-                v = "\t".join([str(x) for x in v])
+                v = "\t".join(str(x) for x in v)
             else:
                 v = str(v)
             v = str(v)
