@@ -631,7 +631,7 @@ class Variable(Node, Generic[_TypeType, OptionalApplyType]):
         if not hasattr(self, "_fn_cache"):
             self._fn_cache: dict = dict()
 
-        inputs = tuple(sorted(parsed_inputs_to_values.keys(), key=id))
+        inputs = tuple(sorted(parsed_inputs_to_values, key=id))
         cache_key = (inputs, tuple(kwargs.items()))
         try:
             fn = self._fn_cache[cache_key]
@@ -748,7 +748,7 @@ class NominalVariable(AtomicVariable[_TypeType]):
             return True
 
         return (
-            type(self) == type(other)
+            type(self) is type(other)
             and self.id == other.id
             and self.type == other.type
         )
@@ -986,7 +986,7 @@ def explicit_graph_inputs(
 
 
 def vars_between(
-    ins: Collection[Variable], outs: Iterable[Variable]
+    ins: Iterable[Variable], outs: Iterable[Variable]
 ) -> Generator[Variable, None, None]:
     r"""Extract the `Variable`\s within the sub-graph between input and output nodes.
 
@@ -1006,6 +1006,8 @@ def vars_between(
 
     """
 
+    ins = set(ins)
+
     def expand(r: Variable) -> Iterable[Variable] | None:
         if r.owner and r not in ins:
             return reversed(r.owner.inputs + r.owner.outputs)
@@ -1034,7 +1036,10 @@ def orphans_between(
 
     Examples
     --------
-    >>> orphans_between([x], [(x+y).out])
+    >>> from pytensor.graph.basic import orphans_between
+    >>> from pytensor.tensor import scalars
+    >>> x, y = scalars("xy")
+    >>> list(orphans_between([x], [(x+y)]))
     [y]
 
     """
@@ -1302,8 +1307,8 @@ def clone_node_and_cache(
 
 
 def clone_get_equiv(
-    inputs: Sequence[Variable],
-    outputs: Sequence[Variable],
+    inputs: Iterable[Variable],
+    outputs: Reversible[Variable],
     copy_inputs: bool = True,
     copy_orphans: bool = True,
     memo: dict[Union[Apply, Variable, "Op"], Union[Apply, Variable, "Op"]]
@@ -1474,9 +1479,8 @@ def general_toposort(
 
     _clients: dict[T, list[T]] = {}
     sources: deque[T] = deque()
-    search_res_len: int = 0
+    search_res_len = len(search_res)
     for snode, children in search_res:
-        search_res_len += 1
         if children:
             for child in children:
                 _clients.setdefault(child, []).append(snode)
