@@ -168,7 +168,7 @@ class MissingInputError(Exception):
     def __init__(self, *args, **kwargs):
         if kwargs:
             # The call to list is needed for Python 3
-            assert list(kwargs.keys()) == ["variable"]
+            assert list(kwargs) == ["variable"]
             error_msg = get_variable_trace_string(kwargs["variable"])
             if error_msg:
                 args = (*args, error_msg)
@@ -229,7 +229,7 @@ class MetaType(ABCMeta):
             if "__eq__" not in dct:
 
                 def __eq__(self, other):
-                    return type(self) == type(other) and tuple(
+                    return type(self) is type(other) and tuple(
                         getattr(self, a) for a in props
                     ) == tuple(getattr(other, a) for a in props)
 
