@@ -524,12 +524,13 @@ class WrapLinker(Linker):
         thunk_groups = list(zip(*thunk_lists))
         order = [x[0] for x in zip(*order_lists)]
 
-        to_reset = []
-        for thunks, node in zip(thunk_groups, order):
-            for j, output in enumerate(node.outputs):
-                if output in no_recycling:
-                    for thunk in thunks:
-                        to_reset.append(thunk.outputs[j])
+        to_reset = [
+            thunk.outputs[j]
+            for thunks, node in zip(thunk_groups, order)
+            for j, output in enumerate(node.outputs)
+            if output in no_recycling
+            for thunk in thunks
+        ]
 
         wrapper = self.wrapper
         pre = self.pre
@@ -600,6 +601,10 @@ class JITLinker(PerformLinker):
     def jit_compile(self, fn: Callable) -> Callable:
         """JIT compile a converted ``FunctionGraph``."""
 
+    def input_filter(self, inp: Any) -> Any:
+        """Apply a filter to the data input."""
+        return inp
+
     def output_filter(self, var: Variable, out: Any) -> Any:
         """Apply a filter to the data output by a JITed function call."""
         return out
@@ -657,7 +662,7 @@ class JITLinker(PerformLinker):
             thunk_inputs=thunk_inputs,
             thunk_outputs=thunk_outputs,
         ):
-            outputs = fgraph_jit(*[x[0] for x in thunk_inputs])
+            outputs = fgraph_jit(*[self.input_filter(x[0]) for x in thunk_inputs])
 
             for o_var, o_storage, o_val in zip(fgraph.outputs, thunk_outputs, outputs):
                 compute_map[o_var][0] = True
@@ -692,18 +697,16 @@ class JITLinker(PerformLinker):
         computed, last_user = gc_helper(nodes)
 
         if self.allow_gc:
-            post_thunk_old_storage = []
-
-            for node in nodes:
-                post_thunk_old_storage.append(
-                    [
-                        storage_map[input]
-                        for input in node.inputs
-                        if (input in computed)
-                        and (input not in fgraph.outputs)
-                        and (node == last_user[input])
-                    ]
-                )
+            post_thunk_old_storage = [
+                [
+                    storage_map[input]
+                    for input in node.inputs
+                    if (input in computed)
+                    and (input not in fgraph.outputs)
+                    and (node == last_user[input])
+                ]
+                for node in nodes
+            ]
         else:
             post_thunk_old_storage = None
 
