@@ -235,16 +235,16 @@ def struct_gen(args, struct_builders, blocks, sub):
     behavior = code_gen(blocks)
 
     # declares the storage
-    storage_decl = "\n".join([f"PyObject* {arg};" for arg in args])
+    storage_decl = "\n".join(f"PyObject* {arg};" for arg in args)
     # in the constructor, sets the storage to the arguments
-    storage_set = "\n".join([f"this->{arg} = {arg};" for arg in args])
+    storage_set = "\n".join(f"this->{arg} = {arg};" for arg in args)
     # increments the storage's refcount in the constructor
-    storage_incref = "\n".join([f"Py_XINCREF({arg});" for arg in args])
+    storage_incref = "\n".join(f"Py_XINCREF({arg});" for arg in args)
     # decrements the storage's refcount in the destructor
-    storage_decref = "\n".join([f"Py_XDECREF(this->{arg});" for arg in args])
+    storage_decref = "\n".join(f"Py_XDECREF(this->{arg});" for arg in args)
 
     args_names = ", ".join(args)
-    args_decl = ", ".join([f"PyObject* {arg}" for arg in args])
+    args_decl = ", ".join(f"PyObject* {arg}" for arg in args)
 
     # The following code stores the exception data in __ERROR, which
     # is a special field of the struct. __ERROR is a list of length 3
@@ -354,9 +354,7 @@ def get_c_declare(fgraph, r, name, sub):
     # it means they need `r`'s dtype to be declared, so
     # we have to pass `check_input=True` to `c_declare`.
     if any(
-        getattr(c.op, "check_input", config.check_input)
-        for (c, _) in fgraph.clients[r]
-        if not isinstance(c, str)
+        getattr(c.op, "check_input", config.check_input) for (c, _) in fgraph.clients[r]
     ) or (r.owner and getattr(r.owner.op, "check_input", config.check_input)):
         c_declare = r.type.c_declare(name, sub, True)
     else:
@@ -1129,19 +1127,18 @@ class CLinker(Linker):
         )
 
     def get_init_tasks(self):
-        init_tasks = []
-        tasks = []
+        vars = [v for v in self.variables if v not in self.consts]
         id = 1
-        for v in self.variables:
-            if v in self.consts:
-                continue
-            init_tasks.append((v, "init", id))
-            tasks.append((v, "get", id + 1))
-            id += 2
-        for node in self.node_order:
-            tasks.append((node, "code", id))
-            init_tasks.append((node, "init", id + 1))
-            id += 2
+        init_tasks = [(v, "init", id + 2 * i) for i, v in enumerate(vars)]
+        tasks = [(v, "get", id + 2 * i + 1) for i, v in enumerate(vars)]
+
+        id += 2 * len(vars)
+        tasks.extend(
+            (node, "code", id + 2 * i) for i, node in enumerate(self.node_order)
+        )
+        init_tasks.extend(
+            (node, "init", id + 2 * i + 1) for i, node in enumerate(self.node_order)
+        )
         return init_tasks, tasks
 
     def make_thunk(
@@ -1492,12 +1489,11 @@ class CLinker(Linker):
         # graph's information used to compute the key. If we mistakenly
         # pretend that inputs with clients don't have any, were are only using
         # those inputs more than once to compute the key.
-        for ipos, var in [
-            (i, var)
-            for i, var in enumerate(fgraph.inputs)
+        sig.extend(
+            (var.type, in_sig(var, -1, ipos))
+            for ipos, var in enumerate(fgraph.inputs)
             if not len(fgraph.clients[var])
-        ]:
-            sig.append((var.type, in_sig(var, -1, ipos)))
+        )
 
         # crystalize the signature and version
         sig = tuple(sig)
