@@ -1,8 +1,8 @@
 import inspect
-import os
 import re
 import warnings
-from collections.abc import Callable, Collection
+from collections.abc import Callable, Collection, Iterable
+from pathlib import Path
 from re import Pattern
 from typing import TYPE_CHECKING, Any, ClassVar, cast
 
@@ -220,12 +220,7 @@ int main( int argc, const char* argv[] )
 
 def lquote_macro(txt: str) -> str:
     """Turn the last line of text into a ``\\``-commented line."""
-    res = []
-    spl = txt.split("\n")
-    for l in spl[:-1]:
-        res.append(l + " \\")
-    res.append(spl[-1])
-    return "\n".join(res)
+    return " \\\n".join(txt.split("\n"))
 
 
 def get_sub_macros(sub: dict[str, str]) -> tuple[str, str]:
@@ -240,21 +235,17 @@ def get_sub_macros(sub: dict[str, str]) -> tuple[str, str]:
     return "\n".join(define_macros), "\n".join(undef_macros)
 
 
-def get_io_macros(
-    inputs: list[str], outputs: list[str]
-) -> tuple[list[str]] | tuple[str, str]:
-    define_macros = []
-    undef_macros = []
+def get_io_macros(inputs: list[str], outputs: list[str]) -> tuple[str, str]:
+    define_inputs = [f"#define INPUT_{int(i)} {inp}" for i, inp in enumerate(inputs)]
+    define_outputs = [f"#define OUTPUT_{int(i)} {out}" for i, out in enumerate(outputs)]
 
-    for i, inp in enumerate(inputs):
-        define_macros.append(f"#define INPUT_{int(i)} {inp}")
-        undef_macros.append(f"#undef INPUT_{int(i)}")
+    undef_inputs = [f"#undef INPUT_{int(i)}" for i in range(len(inputs))]
+    undef_outputs = [f"#undef OUTPUT_{int(i)}" for i in range(len(outputs))]
 
-    for i, out in enumerate(outputs):
-        define_macros.append(f"#define OUTPUT_{int(i)} {out}")
-        undef_macros.append(f"#undef OUTPUT_{int(i)}")
+    define_all = "\n".join(define_inputs + define_outputs)
+    undef_all = "\n".join(undef_inputs + undef_outputs)
 
-    return "\n".join(define_macros), "\n".join(undef_macros)
+    return define_all, undef_all
 
 
 class ExternalCOp(COp):
@@ -288,28 +279,32 @@ class ExternalCOp(COp):
     _cop_num_outputs: int | None = None
 
     @classmethod
-    def get_path(cls, f: str) -> str:
+    def get_path(cls, f: Path) -> Path:
         """Convert a path relative to the location of the class file into an absolute path.
 
         Paths that are already absolute are passed through unchanged.
 
         """
-        if not os.path.isabs(f):
+        if not f.is_absolute():
             class_file = inspect.getfile(cls)
-            class_dir = os.path.dirname(class_file)
-            f = os.path.realpath(os.path.join(class_dir, f))
+            class_dir = Path(class_file).parent
+            f = (class_dir / f).resolve()
         return f
 
-    def __init__(self, func_files: str | list[str], func_name: str | None = None):
+    def __init__(
+        self,
+        func_files: str | Path | list[str] | list[Path],
+        func_name: str | None = None,
+    ):
         """
         Sections are loaded from files in order with sections in later
         files overriding sections in previous files.
 
         """
         if not isinstance(func_files, list):
-            self.func_files = [func_files]
+            self.func_files = [Path(func_files)]
         else:
-            self.func_files = func_files
+            self.func_files = [Path(func_file) for func_file in func_files]
 
         self.func_codes: list[str] = []
         # Keep the original name. If we reload old pickle, we want to
@@ -334,22 +329,20 @@ class ExternalCOp(COp):
                     "Cannot have an `op_code_cleanup` section and specify `func_name`"
                 )
 
-    def load_c_code(self, func_files: list[str]) -> None:
+    def load_c_code(self, func_files: Iterable[Path]) -> None:
         """Loads the C code to perform the `Op`."""
-        func_files = [self.get_path(f) for f in func_files]
         for func_file in func_files:
-            with open(func_file) as f:
-                self.func_codes.append(f.read())
+            func_file = self.get_path(func_file)
+            self.func_codes.append(func_file.read_text(encoding="utf-8"))
 
         # If both the old section markers and the new section markers are
         # present, raise an error because we don't know which ones to follow.
-        old_markers_present = False
-        new_markers_present = False
-        for code in self.func_codes:
-            if self.backward_re.search(code):
-                old_markers_present = True
-            if self.section_re.search(code):
-                new_markers_present = True
+        old_markers_present = any(
+            self.backward_re.search(code) for code in self.func_codes
+        )
+        new_markers_present = any(
+            self.section_re.search(code) for code in self.func_codes
+        )
 
         if old_markers_present and new_markers_present:
             raise ValueError(
@@ -359,7 +352,7 @@ class ExternalCOp(COp):
                 "be used at the same time."
             )
 
-        for i, code in enumerate(self.func_codes):
+        for func_file, code in zip(func_files, self.func_codes):
             if self.backward_re.search(code):
                 # This is backward compat code that will go away in a while
 
@@ -380,7 +373,7 @@ class ExternalCOp(COp):
                 if split[0].strip() != "":
                     raise ValueError(
                         "Stray code before first #section "
-                        f"statement (in file {func_files[i]}): {split[0]}"
+                        f"statement (in file {func_file}): {split[0]}"
                     )
 
                 # Separate the code into the proper sections
@@ -388,7 +381,7 @@ class ExternalCOp(COp):
                 while n < len(split):
                     if split[n] not in self.SECTIONS:
                         raise ValueError(
-                            f"Unknown section type (in file {func_files[i]}): {split[n]}"
+                            f"Unknown section type (in file {func_file}): {split[n]}"
                         )
                     if split[n] not in self.code_sections:
                         self.code_sections[split[n]] = ""
@@ -397,7 +390,7 @@ class ExternalCOp(COp):
 
             else:
                 raise ValueError(
-                    f"No valid section marker was found in file {func_files[i]}"
+                    f"No valid section marker was found in file {func_file}"
                 )
 
     def __get_op_params(self) -> list[tuple[str, Any]]:
@@ -560,9 +553,10 @@ class ExternalCOp(COp):
         define_macros.append(define_template % ("APPLY_SPECIFIC(str)", f"str##_{name}"))
         undef_macros.append(undef_template % "APPLY_SPECIFIC")
 
-        for n, v in self.__get_op_params():
-            define_macros.append(define_template % (n, v))
-            undef_macros.append(undef_template % (n,))
+        define_macros.extend(
+            define_template % (n, v) for n, v in self.__get_op_params()
+        )
+        undef_macros.extend(undef_template % (n,) for n, _ in self.__get_op_params())
 
         return "\n".join(define_macros), "\n".join(undef_macros)
 
