@@ -263,12 +263,7 @@ class Params(dict):
 
     def __repr__(self):
         return "Params({})".format(
-            ", ".join(
-                [
-                    (f"{k}:{type(self[k]).__name__}:{self[k]}")
-                    for k in sorted(self.keys())
-                ]
-            )
+            ", ".join((f"{k}:{type(self[k]).__name__}:{self[k]}") for k in sorted(self))
         )
 
     def __getattr__(self, key):
@@ -301,7 +296,7 @@ class Params(dict):
 
     def __eq__(self, other):
         return (
-            type(self) == type(other)
+            type(self) is type(other)
             and self.__params_type__ == other.__params_type__
             and all(
                 # NB: Params object should have been already filtered.
@@ -365,7 +360,7 @@ class ParamsType(CType):
                 )
 
         self.length = len(kwargs)
-        self.fields = tuple(sorted(kwargs.keys()))
+        self.fields = tuple(sorted(kwargs))
         self.types = tuple(kwargs[field] for field in self.fields)
         self.name = self.generate_struct_name()
 
@@ -428,14 +423,12 @@ class ParamsType(CType):
 
     def __repr__(self):
         return "ParamsType<{}>".format(
-            ", ".join(
-                [(f"{self.fields[i]}:{self.types[i]}") for i in range(self.length)]
-            )
+            ", ".join((f"{self.fields[i]}:{self.types[i]}") for i in range(self.length))
         )
 
     def __eq__(self, other):
         return (
-            type(self) == type(other)
+            type(self) is type(other)
             and self.fields == other.fields
             and self.types == other.types
         )
@@ -751,10 +744,8 @@ class ParamsType(CType):
         }}
         """.format(
             "\n".join(
-                [
-                    ("case %d: extract_%s(object); break;" % (i, self.fields[i]))
-                    for i in range(self.length)
-                ]
+                ("case %d: extract_%s(object); break;" % (i, self.fields[i]))
+                for i in range(self.length)
             )
         )
         final_struct_code = """
