@@ -246,10 +246,8 @@ class VM(ABC):
         for node, thunk, t, c in zip(
             self.nodes, self.thunks, self.call_times, self.call_counts
         ):
-            profile.apply_time.setdefault((self.fgraph, node), 0.0)
             profile.apply_time[(self.fgraph, node)] += t
 
-            profile.apply_callcount.setdefault((self.fgraph, node), 0)
             profile.apply_callcount[(self.fgraph, node)] += c
 
             profile.apply_cimpl[node] = hasattr(thunk, "cthunk")
@@ -956,8 +954,7 @@ class VMLinker(LocalLinker):
             if k.owner and self.fgraph.clients[k]:
                 ls = []
                 for cl in self.fgraph.clients[k]:
-                    if cl[0] != "output":
-                        ls += cl[0].outputs
+                    ls += cl[0].outputs
                 dependencies[k] += ls
         return dependencies
 
@@ -993,7 +990,7 @@ class VMLinker(LocalLinker):
         for pair in reallocated_info.values():
             storage_map[pair[1]] = storage_map[pair[0]]
 
-        return tuple(reallocated_info.keys())
+        return tuple(reallocated_info)
 
     def make_vm(
         self,
@@ -1111,12 +1108,11 @@ class VMLinker(LocalLinker):
             # builds the list of prereqs induced by e.g. destroy_handler
             ords = self.fgraph.orderings()
             node_prereqs = []
-            node_output_size = []
+            node_output_size = [0] * len(nodes)
             for i, node in enumerate(nodes):
-                node_output_size.append(0)
                 prereq_var_idxs = []
                 for prereq_node in ords.get(node, []):
-                    prereq_var_idxs.extend([vars_idx[v] for v in prereq_node.outputs])
+                    prereq_var_idxs.extend(vars_idx[v] for v in prereq_node.outputs)
                 prereq_var_idxs = list(set(prereq_var_idxs))
                 prereq_var_idxs.sort()  # TODO: why sort?
                 node_prereqs.append(prereq_var_idxs)
@@ -1327,9 +1323,7 @@ class VMLinker(LocalLinker):
 
     def __repr__(self):
         args_str = ", ".join(
-            [
-                f"{name}={getattr(self, name)}"
-                for name in ("use_cloop", "lazy", "allow_partial_eval", "allow_gc")
-            ]
+            f"{name}={getattr(self, name)}"
+            for name in ("use_cloop", "lazy", "allow_partial_eval", "allow_gc")
         )
         return f"{type(self).__name__}({args_str})"
