@@ -4,8 +4,8 @@ r"""
 As SciPy is not always available, we treat them separately.
 """
 
-import os
 from functools import reduce
+from pathlib import Path
 from textwrap import dedent
 
 import numpy as np
@@ -47,6 +47,9 @@ from pytensor.scalar.basic import abs as scalar_abs
 from pytensor.scalar.loop import ScalarLoop
 
 
+C_CODE_PATH = Path(__file__).parent / "c_code"
+
+
 class Erf(UnaryScalarOp):
     nfunc_spec = ("scipy.special.erf", 1, 1)
 
@@ -154,19 +157,12 @@ class Erfcx(UnaryScalarOp):
 
     def c_header_dirs(self, **kwargs):
         # Using the Faddeeva.hh (c++) header for Faddeevva.cc
-        res = [
-            *super().c_header_dirs(**kwargs),
-            os.path.join(os.path.dirname(__file__), "c_code"),
-        ]
+        res = [*super().c_header_dirs(**kwargs), str(C_CODE_PATH)]
         return res
 
     def c_support_code(self, **kwargs):
         # Using Faddeeva.cc source file from: http://ab-initio.mit.edu/wiki/index.php/Faddeeva_Package
-        with open(
-            os.path.join(os.path.dirname(__file__), "c_code", "Faddeeva.cc")
-        ) as f:
-            raw = f.read()
-            return raw
+        return (C_CODE_PATH / "Faddeeva.cc").read_text(encoding="utf-8")
 
     def c_code(self, node, name, inp, out, sub):
         (x,) = inp
@@ -612,9 +608,7 @@ class Chi2SF(BinaryScalarOp):
         return Chi2SF.st_impl(x, k)
 
     def c_support_code(self, **kwargs):
-        with open(os.path.join(os.path.dirname(__file__), "c_code", "gamma.c")) as f:
-            raw = f.read()
-            return raw
+        return (C_CODE_PATH / "gamma.c").read_text(encoding="utf-8")
 
     def c_code(self, node, name, inp, out, sub):
         x, k = inp
@@ -626,7 +620,7 @@ class Chi2SF(BinaryScalarOp):
         raise NotImplementedError("only floatingpoint is implemented")
 
     def __eq__(self, other):
-        return type(self) == type(other)
+        return type(self) is type(other)
 
     def __hash__(self):
         return hash(type(self))
@@ -665,9 +659,7 @@ class GammaInc(BinaryScalarOp):
         ]
 
     def c_support_code(self, **kwargs):
-        with open(os.path.join(os.path.dirname(__file__), "c_code", "gamma.c")) as f:
-            raw = f.read()
-            return raw
+        return (C_CODE_PATH / "gamma.c").read_text(encoding="utf-8")
 
     def c_code(self, node, name, inp, out, sub):
         k, x = inp
@@ -679,7 +671,7 @@ class GammaInc(BinaryScalarOp):
         raise NotImplementedError("only floatingpoint is implemented")
 
     def __eq__(self, other):
-        return type(self) == type(other)
+        return type(self) is type(other)
 
     def __hash__(self):
         return hash(type(self))
@@ -718,9 +710,7 @@ class GammaIncC(BinaryScalarOp):
         ]
 
     def c_support_code(self, **kwargs):
-        with open(os.path.join(os.path.dirname(__file__), "c_code", "gamma.c")) as f:
-            raw = f.read()
-            return raw
+        return (C_CODE_PATH / "gamma.c").read_text(encoding="utf-8")
 
     def c_code(self, node, name, inp, out, sub):
         k, x = inp
@@ -732,7 +722,7 @@ class GammaIncC(BinaryScalarOp):
         raise NotImplementedError("only floatingpoint is implemented")
 
     def __eq__(self, other):
-        return type(self) == type(other)
+        return type(self) is type(other)
 
     def __hash__(self):
         return hash(type(self))
@@ -1031,9 +1021,7 @@ class GammaU(BinaryScalarOp):
         return GammaU.st_impl(k, x)
 
     def c_support_code(self, **kwargs):
-        with open(os.path.join(os.path.dirname(__file__), "c_code", "gamma.c")) as f:
-            raw = f.read()
-            return raw
+        return (C_CODE_PATH / "gamma.c").read_text(encoding="utf-8")
 
     def c_code(self, node, name, inp, out, sub):
         k, x = inp
@@ -1045,7 +1033,7 @@ class GammaU(BinaryScalarOp):
         raise NotImplementedError("only floatingpoint is implemented")
 
     def __eq__(self, other):
-        return type(self) == type(other)
+        return type(self) is type(other)
 
     def __hash__(self):
         return hash(type(self))
@@ -1069,9 +1057,7 @@ class GammaL(BinaryScalarOp):
         return GammaL.st_impl(k, x)
 
     def c_support_code(self, **kwargs):
-        with open(os.path.join(os.path.dirname(__file__), "c_code", "gamma.c")) as f:
-            raw = f.read()
-            return raw
+        return (C_CODE_PATH / "gamma.c").read_text(encoding="utf-8")
 
     def c_code(self, node, name, inp, out, sub):
         k, x = inp
@@ -1083,7 +1069,7 @@ class GammaL(BinaryScalarOp):
         raise NotImplementedError("only floatingpoint is implemented")
 
     def __eq__(self, other):
-        return type(self) == type(other)
+        return type(self) is type(other)
 
     def __hash__(self):
         return hash(type(self))
@@ -1495,8 +1481,23 @@ class BetaInc(ScalarOp):
             ),
         ]
 
-    def c_code(self, *args, **kwargs):
-        raise NotImplementedError()
+    def c_support_code(self, **kwargs):
+        return (C_CODE_PATH / "incbet.c").read_text(encoding="utf-8")
+
+    def c_code(self, node, name, inp, out, sub):
+        (a, b, x) = inp
+        (z,) = out
+        if (
+            node.inputs[0].type in float_types
+            and node.inputs[1].type in float_types
+            and node.inputs[2].type in float_types
+        ):
+            return f"""{z} = BetaInc({a}, {b}, {x});"""
+
+        raise NotImplementedError("type not supported", type)
+
+    def c_code_cache_version(self):
+        return (2,)
 
 
 betainc = BetaInc(upgrade_to_float_no_complex, name="betainc")
