@@ -138,7 +138,7 @@ class TensorType(CType[np.ndarray], HasDataType, HasShape):
             shape = self.shape
         return type(self)(dtype, shape, name=self.name)
 
-    def filter(self, data, strict=False, allow_downcast=None):
+    def filter(self, data, strict=False, allow_downcast=None) -> np.ndarray:
         """Convert `data` to something which can be associated to a `TensorVariable`.
 
         This function is not meant to be called in user code. It is for
@@ -370,7 +370,7 @@ class TensorType(CType[np.ndarray], HasDataType, HasShape):
         return values_eq_approx(a, b, allow_remove_inf, allow_remove_nan, rtol, atol)
 
     def __eq__(self, other):
-        if type(self) != type(other):
+        if type(self) is not type(other):
             return NotImplemented
 
         return other.dtype == self.dtype and other.shape == self.shape
@@ -401,7 +401,7 @@ class TensorType(CType[np.ndarray], HasDataType, HasShape):
                 else:
                     return str(s)
 
-            formatted_shape = ", ".join([shape_str(s) for s in shape])
+            formatted_shape = ", ".join(shape_str(s) for s in shape)
             if len_shape == 1:
                 formatted_shape += ","
 
@@ -624,7 +624,7 @@ class TensorType(CType[np.ndarray], HasDataType, HasShape):
 
 class DenseTypeMeta(MetaType):
     def __instancecheck__(self, o):
-        if type(o) == TensorType or isinstance(o, DenseTypeMeta):
+        if type(o) is TensorType or isinstance(o, DenseTypeMeta):
             return True
         return False
 
