@@ -1,13 +1,16 @@
 import re
 from collections.abc import Sequence
+from typing import cast
 
 import numpy as np
+from numpy.core.numeric import normalize_axis_tuple  # type: ignore
 
 import pytensor
+from pytensor.graph import FunctionGraph, Variable
 from pytensor.utils import hash_from_code
 
 
-def hash_from_ndarray(data):
+def hash_from_ndarray(data) -> str:
     """
     Return a hash from an ndarray.
 
@@ -34,7 +37,9 @@ def hash_from_ndarray(data):
     )
 
 
-def shape_of_variables(fgraph, input_shapes):
+def shape_of_variables(
+    fgraph: FunctionGraph, input_shapes
+) -> dict[Variable, tuple[int, ...]]:
     """
     Compute the numeric shape of all intermediate variables given input shapes.
 
@@ -54,8 +59,9 @@ def shape_of_variables(fgraph, input_shapes):
 
     Examples
     --------
-    >>> import pytensor
-    >>> x = pytensor.tensor.matrix('x')
+    >>> import pytensor.tensor as pt
+    >>> from pytensor.graph.fg import FunctionGraph
+    >>> x = pt.matrix('x')
     >>> y = x[512:]; y.name = 'y'
     >>> fgraph = FunctionGraph([x], [y], clone=False)
     >>> d = shape_of_variables(fgraph, {x: (1024, 1024)})
@@ -70,21 +76,19 @@ def shape_of_variables(fgraph, input_shapes):
 
         fgraph.attach_feature(ShapeFeature())
 
+    shape_feature = fgraph.shape_feature  # type: ignore[attr-defined]
+
     input_dims = [
-        dimension
-        for inp in fgraph.inputs
-        for dimension in fgraph.shape_feature.shape_of[inp]
+        dimension for inp in fgraph.inputs for dimension in shape_feature.shape_of[inp]
     ]
 
     output_dims = [
-        dimension
-        for shape in fgraph.shape_feature.shape_of.values()
-        for dimension in shape
+        dimension for shape in shape_feature.shape_of.values() for dimension in shape
     ]
 
     compute_shapes = pytensor.function(input_dims, output_dims)
 
-    if any(i not in fgraph.inputs for i in input_shapes.keys()):
+    if any(i not in fgraph.inputs for i in input_shapes):
         raise ValueError(
             "input_shapes keys aren't in the fgraph.inputs. FunctionGraph()"
             " interface changed. Now by default, it clones the graph it receives."
@@ -97,10 +101,8 @@ def shape_of_variables(fgraph, input_shapes):
     sym_to_num_dict = dict(zip(output_dims, numeric_output_dims))
 
     l = {}
-    for var in fgraph.shape_feature.shape_of:
-        l[var] = tuple(
-            sym_to_num_dict[sym] for sym in fgraph.shape_feature.shape_of[var]
-        )
+    for var in shape_feature.shape_of:
+        l[var] = tuple(sym_to_num_dict[sym] for sym in shape_feature.shape_of[var])
     return l
 
 
@@ -174,7 +176,7 @@ _SIGNATURE = f"^(?:{_ARGUMENT_LIST})?->{_ARGUMENT_LIST}$"
 
 
 def _parse_gufunc_signature(
-    signature,
+    signature: str,
 ) -> tuple[
     list[tuple[str, ...]], ...
 ]:  # mypy doesn't know it's alwayl a length two tuple
@@ -222,3 +224,19 @@ def safe_signature(
         operand_sig(ndim, prefix=f"o{n}") for n, ndim in enumerate(core_outputs_ndim)
     )
     return f"{inputs_sig}->{outputs_sig}"
+
+
+def normalize_reduce_axis(axis, ndim: int) -> tuple[int, ...] | None:
+    """Normalize the axis parameter for reduce operations."""
+    if axis is None:
+        return None
+
+    # scalar inputs are treated as 1D regarding axis in reduce operations
+    if axis is not None:
+        try:
+            axis = normalize_axis_tuple(axis, ndim=max(1, ndim))
+        except np.AxisError:
+            raise np.AxisError(axis, ndim=ndim)
+
+    # TODO: If axis tuple is equivalent to None, return None for more canonicalization?
+    return cast(tuple, axis)
